#!/bin/bash

set -e

echo "Updating package lists..."
sudo apt-get update -y

echo "Installing build dependencies..."
sudo apt-get install -y \
    python3.9 \
    python3.9-dev \
    python3.9-venv \
    python3-pip \
    build-essential \
    libssl-dev \
    libffi-dev \
    zlib1g-dev \
    libbz2-dev \
    libreadline-dev \
    libsqlite3-dev \
    libgdbm-dev \
    libncurses5-dev \
    libncursesw5-dev \
    liblzma-dev \
    uuid-dev \
    tk-dev \
    libxml2-dev \
    libxmlsec1-dev \
    libmpdec-dev \
    wget \
    curl \
    llvm \
    xz-utils \
    patchelf \
    gcc \
    make \
    pkg-config

# Ensure pip is up to date
echo "Upgrading pip..."
python3.9 -m ensurepip --upgrade
python3.9 -m pip install --upgrade pip

# Add Python and pip to PATH (in case it's not already there)
echo 'export PATH="$HOME/.local/bin:$PATH"' >> ~/.bashrc
source ~/.bashrc

# Install essential Python build tools
echo "Installing Python build tools..."
python3.9 -m pip install wheel setuptools

# Install PyInstaller
echo "Installing PyInstaller and other Python dependencies..."
python3.9 -m pip install pyinstaller

# Verify installation
echo "Verifying installation..."
python3.9 --version
pip --version
pyinstaller --version

echo "Setup complete!"